@@ -1,21 +1,25 @@
 # -*- coding: utf-8 -*-
 import json
 import threading
+import time
+
 import paho.mqtt.client as mqtt
 
 server_url = '127.0.0.1'
 server_port = 1883
 callback_dit = {}
-publish_dit = {}
+publish_dit = []
 mqttc = None
 rc = -1
 isPrintLog = False
+client_id = str(int(time.time() * 1000))
 
 
-def setServerUrl(url='127.0.0.1', port=1883):
-    global server_url, server_port
+def setServerUrl(url='127.0.0.1', port=1883, client_idd=str(int(time.time() * 1000))):
+    global server_url, server_port, client_id
     server_url = url
     server_port = port
+    client_id = client_idd
 
 
 def setMqttLog(PrintLog=False):
@@ -85,9 +89,17 @@ class Dxr_Subscriber:
 
 class Dxr_Publisher:
     def __init__(self, topic):
+        global publish_dit
         self.topic = topic
         # 新建mqtt客户端，默认没有clientid，clean_session=True, transport="tcp"
         self.mqttc = Mqtt()
+        if topic not in publish_dit:
+            publish_dit.append(topic)
+        topic_list_str = ''
+        for item in publish_dit:
+            topic_list_str = topic_list_str + item + '\n'
+        print(topic_list_str)
+        self.mqttc.publish('/'+client_id+'/topic', retain=True, payload=topic_list_str)
 
     def publish(self, msg):
         self.mqttc.publish(self.topic, json.dumps(msg), qos=0)
